# Autogenerated by nbdev

d = { 'settings': { 'branch': 'master',
                'doc_baseurl': '/nb-thumb',
                'doc_host': 'https://fastai.github.io',
                'git_url': 'https://github.com/fastai/nb-thumb',
                'lib_path': 'nb_thumb'},
  'syms': { 'nb_thumb.core': {'nb_thumb.core.foo': ('core.html#foo', 'nb_thumb/core.py')},
            'nb_thumb.gallery': { 'nb_thumb.gallery.emb_img': ('gallery.html#emb_img', 'nb_thumb/gallery.py'),
                                  'nb_thumb.gallery.gallery': ('gallery.html#gallery', 'nb_thumb/gallery.py')},
            'nb_thumb.thumb': { 'nb_thumb.thumb._decode_img': ('thumb.html#_decode_img', 'nb_thumb/thumb.py'),
                                'nb_thumb.thumb.get_img': ('thumb.html#get_img', 'nb_thumb/thumb.py'),
                                'nb_thumb.thumb.img2thumb': ('thumb.html#img2thumb', 'nb_thumb/thumb.py'),
                                'nb_thumb.thumb.nb2thumb': ('thumb.html#nb2thumb', 'nb_thumb/thumb.py')}}}
